﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Telerik.OpenAccess.Metadata.Fluent;
using Telerik.OpenAccess.Metadata;

namespace FluentAPI.Model
{
    public class Company : IEntity
    {
        private IList<Location> locations = new List<Location>();

        #region Properties

        public virtual int Id { get; set; }

        public virtual string Name { get; set; }

        //Associations

        public virtual IList<Location> Locations { get { return locations; } }

        #endregion

        //OpenAccess Mapping
        public static MappingConfiguration<Company> CreateConfiguration()
        {
            var config = new MappingConfiguration<Company>();

            config.MapType(c => new
            {
                Id = c.Id,
                Name = c.Name
            })
                                .ToTable("Company");

            config.HasProperty(c => c.Id).IsIdentity(KeyGenerator.Autoinc);

            config.HasProperty(c => c.Name).IsNotNullable();

            config.HasAssociation(c => c.Locations).WithOpposite(l => l.Company).HasFieldName("locations");

            return config;
        }
    }
}
