﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Telerik.OpenAccess.Metadata.Fluent;
using Telerik.OpenAccess.Metadata;

namespace FluentAPI.Model
{
    public class Location : IEntity
    {
        private IList<MsdsItem> msdsItems = new List<MsdsItem>();

        #region Properties

        public virtual int Id { get; set; }

        public virtual string Name { get; set; }

        //Associations

        public virtual Company Company { get; set; }

        public virtual int CompanyId { get; set; }

        public virtual IList<MsdsItem> MsdsItems { get { return msdsItems; } }

        #endregion

        //OpenAccess Mapping
        public static MappingConfiguration<Location> CreateConfiguration()
        {
            var config = new MappingConfiguration<Location>();

            config.MapType(l => new
            {
                Id = l.Id,
                Name = l.Name,
                CompanyId = l.CompanyId
            })
                                .ToTable("Location");

            config.HasProperty(l => l.Id).IsIdentity(KeyGenerator.Autoinc);

            config.HasProperty(l => l.CompanyId).IsNotNullable();

            config.HasAssociation(l => l.MsdsItems).WithOpposite(msds => msds.Location).HasFieldName("msdsItems");

            config.HasAssociation(l => l.Company).WithOpposite(c => c.Locations).HasConstraint((l, c) => l.CompanyId == c.Id);

            return config;
        }
    }
}
