﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Telerik.OpenAccess.Metadata.Fluent;
using Telerik.OpenAccess.Metadata;

namespace FluentAPI.Model
{
    /// <summary>
    /// An example Material Data Safty Sheet (MSDS)
    /// http://en.wikipedia.org/wiki/Material_safety_data_sheet
    /// </summary>
    public class MsdsItem : IEntity
    {
        public MsdsItem()
        {
            this.CreatedDate = DateTime.Today;
        }

        #region Properties

        public virtual int Id { get; set; }

        public virtual string PartNumber { get; set; }

        public virtual string Name { get; set; }

        public virtual string ManufacturerName { get; set; }

        public virtual string ManufacturerAddress { get; set; }

        public virtual string Usage { get; set; }

        public virtual string FileName { get; set; }

        public virtual HazardLevel HealthRisk { get; set; }//NFPA Label

        public virtual HazardLevel FireRisk { get; set; }//NFPA Label

        public virtual HazardLevel ReactivityHazard { get; set; }//NFPA Label

        public virtual SpecialHazard SpecialHazard { get; set; }//NFPA Label

        public virtual string Warning { get; set; }

        public virtual string ProductState { get; set; }

        public virtual string CreatedBy { get; set; }

        public virtual DateTime CreatedDate { get; set; }

        public virtual bool IsArchived { get; set; }

        //Associations

        public virtual int LocationId { get; set; }

        public virtual Location Location { get; set; }

        #endregion

        /// <summary>
        /// OpenAccess Mapping
        /// </summary>
        /// <returns>MappingConfiguration</returns>
        public static MappingConfiguration<MsdsItem> CreateConfiguration()
        {
            var config = new MappingConfiguration<MsdsItem>();
            config.MapType(msds => new
                           {
                               Id = msds.Id,
                               Name = msds.Name,
                               PartNumber = msds.PartNumber,
                               ManufacturerName = msds.ManufacturerName,
                               ManufacturerAddress = msds.ManufacturerAddress,
                               Usage = msds.Usage,
                               FileName = msds.FileName,
                               Hazzard = msds.HealthRisk,
                               Fire = msds.FireRisk,
                               Reactive = msds.ReactivityHazard,
                               Specific = msds.SpecialHazard,
                               Warning = msds.Warning,
                               ProductState = msds.ProductState,
                               CreatedBy = msds.CreatedBy,
                               CreatedDate = msds.CreatedDate,
                               IsArchived = msds.IsArchived,
                               LocationId = msds.LocationId
                           }).ToTable("MSDSItem");

            config.HasProperty(msds => msds.Id).IsIdentity(KeyGenerator.Autoinc);

            config.HasProperty(msds => msds.LocationId).IsNotNullable();

            config.HasAssociation(msds => msds.Location).WithOpposite(l => l.MsdsItems).HasConstraint((msds, l) => msds.LocationId == l.Id);

            return config;
        }
    }
}
